@@ -1,7 +1,7 @@
 use v5.14.0;
 use warnings;
 
-package JMAP::Tester 0.105;
+package JMAP::Tester 0.106;
 # ABSTRACT: a JMAP client made for testing JMAP servers
 
 use Moo;
@@ -174,6 +174,24 @@ has ua => (
   },
 );
 
+#pod =attr ident
+#pod
+#pod This is a (preferably short) string that can be used to identify this
+#pod JMAP::Tester object.  It's used in request logging, so that client telemetry
+#pod can be correlated to a specific client object.  If no ident is given, an ident
+#pod will be generated, but it is not guaranteed to be unique.
+#pod
+#pod =cut
+
+has ident => (
+  is => 'ro',
+  default => sub {
+    my ($self) = @_;
+    state $ident_counter = 0;
+    return "jmap-tester-" . (++$ident_counter);
+  }
+);
+
 #pod =attr default_using
 #pod
 #pod This is an arrayref of strings that specify which capabilities the client
@@ -370,7 +388,7 @@ sub request {
     my ($res) = @_;
 
     unless ($res->is_success) {
-      $self->_logger->log_jmap_response({ http_response => $res });
+      $self->_logger->log_jmap_response($self, { http_response => $res });
       return Future->fail(
         JMAP::Tester::Result::Failure->new({ http_response => $res })
       );
@@ -405,11 +423,14 @@ sub _jresponse_from_hresponse {
     abort("illegal response to JMAP request: $data");
   }
 
-  $self->_logger->log_jmap_response({
-    jmap_array    => $items,
-    json          => $json,
-    http_response => $http_res,
-  });
+  $self->_logger->log_jmap_response(
+    $self,
+    {
+      jmap_array    => $items,
+      json          => $json,
+      http_response => $http_res,
+    }
+  );
 
   return $self->response_class->new({
     items => $items,
@@ -492,7 +513,7 @@ sub upload {
     my ($res) = @_;
 
     unless ($res->is_success) {
-      $self->_logger->log_upload_response({ http_response => $res });
+      $self->_logger->log_upload_response($self, { http_response => $res });
       return Future->fail(
         JMAP::Tester::Result::Failure->new({ http_response => $res })
       );
@@ -501,11 +522,14 @@ sub upload {
     my $json = $res->decoded_content;
     my $blob = $self->apply_json_types( $self->json_decode( $json ) );
 
-    $self->_logger->log_upload_response({
-      json          => $json,
-      blob_struct   => $blob,
-      http_response => $res,
-    });
+    $self->_logger->log_upload_response(
+      $self,
+      {
+        json          => $json,
+        blob_struct   => $blob,
+        http_response => $res,
+      }
+    );
 
     return Future->done(
       JMAP::Tester::Result::Upload->new({
@@ -628,9 +652,7 @@ sub download {
   my $future = $res_f->then(sub {
     my ($res) = @_;
 
-    $self->_logger->log_download_response({
-      http_response => $res,
-    });
+    $self->_logger->log_download_response($self, { http_response => $res });
 
     unless ($res->is_success) {
       return Future->fail(
@@ -1051,7 +1073,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.105
+version 0.106
 
 =head1 OVERVIEW
 
@@ -1124,6 +1146,13 @@ return L<Future> objects rather than immediate results.
 This attribute governs the conversion of JSON data into typed objects, using
 L<JSON::Typist>.  This attribute is true by default.
 
+=head2 ident
+
+This is a (preferably short) string that can be used to identify this
+JMAP::Tester object.  It's used in request logging, so that client telemetry
+can be correlated to a specific client object.  If no ident is given, an ident
+will be generated, but it is not guaranteed to be unique.
+
 =head2 default_using
 
 This is an arrayref of strings that specify which capabilities the client
