@@ -1,7 +1,7 @@
 use v5.14.0;
 use warnings;
 
-package JMAP::Tester::UA::Async 0.105;
+package JMAP::Tester::UA::Async 0.106;
 
 use Moo;
 with 'JMAP::Tester::Role::UA';
@@ -90,10 +90,13 @@ sub request {
       my $log_method = "log_" . ($log_type // 'jmap') . '_request';
 
       if ($logger->can($log_method)) {
-        $tester->_logger->$log_method({
-          ($log_extra ? %$log_extra : ()),
-          http_request => $req,
-        });
+        $tester->_logger->$log_method(
+          $tester,
+          {
+            ($log_extra ? %$log_extra : ()),
+            http_request => $req,
+          }
+        );
       }
 
       return Future->done;
@@ -116,7 +119,7 @@ JMAP::Tester::UA::Async
 
 =head1 VERSION
 
-version 0.105
+version 0.106
 
 =head1 PERL VERSION
 
